# This is a hack to force old Homebrew to perform core/formula separation migration.
# On some old system, `brew update` will try to load `tap_migrations.rb` file.
require "migrate_remote"

TAP_MIGRATIONS = {
  "adobe-air-sdk" => "homebrew/binary",
  "afuse" => "homebrew/fuse",
  "aimage" => "homebrew/boneyard",
  "aplus" => "homebrew/boneyard",
  "apple-gcc42" => "homebrew/dupes",
  "appswitch" => "homebrew/binary",
  "archivemount" => "homebrew/fuse",
  "arpon" => "homebrew/boneyard",
  "asm6" => "homebrew/boneyard",
  "atari++" => "homebrew/x11",
  "auctex" => "homebrew/tex",
  "authexec" => "homebrew/boneyard",
  "avfs" => "homebrew/fuse",
  "aws-iam-tools" => "homebrew/boneyard",
  "awsenv" => "Luzifer/tools",
  "bbcp" => "homebrew/head-only",
  "bcwipe" => "homebrew/boneyard",
  "bindfs" => "homebrew/fuse",
  "bochs" => "homebrew/x11",
  "boost149" => "homebrew/versions",
  "cantera" => "homebrew/science",
  "cardpeek" => "homebrew/gui",
  "catdoc" => "homebrew/boneyard",
  "cdf" => "homebrew/boneyard",
  "cdimgtools" => "homebrew/boneyard",
  "celt" => "homebrew/boneyard",
  "chktex" => "homebrew/tex",
  "clam" => "homebrew/boneyard",
  "clay" => "homebrew/boneyard",
  "cloudfoundry-cli" => "pivotal/tap",
  "clusterit" => "homebrew/x11",
  "cmucl" => "homebrew/binary",
  "comparepdf" => "homebrew/boneyard",
  "coremod" => "homebrew/boneyard",
  "curlftpfs" => "homebrew/x11",
  "cwm" => "homebrew/x11",
  "dart" => "dart-lang/dart",
  "datamash" => "homebrew/science",
  "dbslayer" => "homebrew/boneyard",
  "ddd" => "homebrew/x11",
  "denyhosts" => "homebrew/boneyard",
  "dgtal" => "homebrew/science",
  "djmount" => "homebrew/fuse",
  "dmenu" => "homebrew/x11",
  "dotwrp" => "homebrew/science",
  "drizzle" => "homebrew/boneyard",
  "drush" => "homebrew/php",
  "dsniff" => "homebrew/boneyard",
  "dupx" => "homebrew/boneyard",
  "dwm" => "homebrew/x11",
  "dzen2" => "homebrew/x11",
  "easy-tag" => "homebrew/gui",
  "echoping" => "homebrew/boneyard",
  "electric-fence" => "homebrew/boneyard",
  "encfs" => "homebrew/fuse",
  "ext2fuse" => "homebrew/fuse",
  "ext4fuse" => "homebrew/fuse",
  "fceux" => "homebrew/games",
  "feh" => "homebrew/x11",
  "ffts" => "homebrew/boneyard",
  "figtoipe" => "homebrew/head-only",
  "fleet-db" => "homebrew/boneyard",
  "fox" => "homebrew/x11",
  "freeglut" => "homebrew/x11",
  "freerdp" => "homebrew/x11",
  "fsv" => "homebrew/boneyard",
  "fuse-zip" => "homebrew/fuse",
  "fuse4x" => "homebrew/fuse",
  "fuse4x-kext" => "homebrew/fuse",
  "gant" => "homebrew/boneyard",
  "gcsfuse" => "homebrew/fuse",
  "gdrive" => "homebrew/boneyard",
  "geda-gaf" => "homebrew/science",
  "geeqie" => "homebrew/gui",
  "geomview" => "homebrew/x11",
  "ggobi" => "homebrew/science",
  "giblib" => "homebrew/x11",
  "git-encrypt" => "homebrew/boneyard",
  "git-flow-clone" => "homebrew/boneyard",
  "git-latexdiff" => "homebrew/tex",
  "gitfs" => "homebrew/fuse",
  "gle" => "homebrew/x11",
  "gnunet" => "homebrew/boneyard",
  "gobby" => "homebrew/gui",
  "googlecl" => "homebrew/boneyard",
  "gpredict" => "homebrew/x11",
  "gptfdisk" => "homebrew/boneyard",
  "grace" => "homebrew/x11",
  "grads" => "homebrew/binary",
  "graylog2-server" => "homebrew/boneyard",
  "gromacs" => "homebrew/science",
  "gsmartcontrol" => "homebrew/gui",
  "gtk-chtheme" => "homebrew/gui",
  "gtkglarea" => "homebrew/boneyard",
  "gtkwave" => "homebrew/gui",
  "guilt" => "homebrew/boneyard",
  "gv" => "homebrew/x11",
  "hatari" => "homebrew/x11",
  "helios" => "spotify/public",
  "hexchat" => "homebrew/gui",
  "hllib" => "homebrew/boneyard",
  "honeyd" => "homebrew/boneyard",
  "hugs98" => "homebrew/boneyard",
  "hwloc" => "homebrew/science",
  "ifuse" => "homebrew/fuse",
  "imake" => "homebrew/x11",
  "inkscape" => "homebrew/gui",
  "iojs" => "homebrew/versions",
  "ipe" => "homebrew/boneyard",
  "ipopt" => "homebrew/science",
  "iptux" => "homebrew/gui",
  "itsol" => "homebrew/science",
  "iulib" => "homebrew/boneyard",
  "jscoverage" => "homebrew/boneyard",
  "jsl" => "homebrew/binary",
  "jstalk" => "homebrew/boneyard",
  "justniffer" => "homebrew/boneyard",
  "kbtin" => "homebrew/boneyard",
  "kerl" => "homebrew/head-only",
  "kernagic" => "homebrew/gui",
  "kismet" => "homebrew/boneyard",
  "klavaro" => "homebrew/gui",
  "kumofs" => "homebrew/boneyard",
  "latex-mk" => "homebrew/tex",
  "libdlna" => "homebrew/boneyard",
  "libgtextutils" => "homebrew/science",
  "libodbc++" => "homebrew/boneyard",
  "libqxt" => "homebrew/boneyard",
  "librets" => "homebrew/boneyard",
  "libspotify" => "homebrew/binary",
  "lilypond" => "homebrew/tex",
  "lmutil" => "homebrew/binary",
  "magit" => "homebrew/emacs",
  "meld" => "homebrew/gui",
  "mesalib-glw" => "homebrew/x11",
  "mess" => "homebrew/games",
  "metalua" => "homebrew/boneyard",
  "mit-scheme" => "homebrew/x11",
  "mlkit" => "homebrew/boneyard",
  "morse" => "homebrew/x11",
  "mp3fs" => "homebrew/fuse",
  "mpio" => "homebrew/boneyard",
  "mscgen" => "homebrew/x11",
  "msgpack-rpc" => "homebrew/boneyard",
  "mupdf" => "homebrew/x11",
  "mysql-connector-odbc" => "homebrew/boneyard",
  "mysql-proxy" => "homebrew/boneyard",
  "mysqlreport" => "homebrew/boneyard",
  "net6" => "homebrew/boneyard",
  "newick-utils" => "homebrew/science",
  "ngrok" => "homebrew/boneyard",
  "nlopt" => "homebrew/science",
  "ntfs-3g" => "homebrew/fuse",
  "octave" => "homebrew/science",
  "opencv" => "homebrew/science",
  "openfst" => "homebrew/science",
  "opengrm-ngram" => "homebrew/science",
  "ori" => "homebrew/fuse",
  "p11-kit" => "homebrew/boneyard",
  "pan" => "homebrew/boneyard",
  "paq8px" => "homebrew/boneyard",
  "par2tbb" => "homebrew/boneyard",
  "pari" => "homebrew/x11",
  "pathfinder" => "homebrew/boneyard",
  "pcb" => "homebrew/science",
  "pdf-tools" => "homebrew/emacs",
  "pdf2image" => "homebrew/x11",
  "pdfjam" => "homebrew/tex",
  "pdftoipe" => "homebrew/head-only",
  "pebble-sdk" => "pebble/pebble-sdk",
  "pgplot" => "homebrew/x11",
  "phash" => "homebrew/boneyard",
  "pixie" => "homebrew/x11",
  "pjsip" => "homebrew/boneyard",
  "pocl" => "homebrew/science",
  "pplatex" => "homebrew/tex",
  "prooftree" => "homebrew/gui",
  "pulse" => "homebrew/boneyard",
  "pyenv-pip-rehash" => "homebrew/boneyard",
  "pyxplot" => "homebrew/x11",
  "qfits" => "homebrew/boneyard",
  "qi" => "homebrew/boneyard",
  "qiv" => "homebrew/boneyard",
  "qrupdate" => "homebrew/science",
  "rdesktop" => "homebrew/x11",
  "rocket" => "homebrew/boneyard",
  "rofs-filtered" => "homebrew/fuse",
  "rubber" => "homebrew/tex",
  "rxvt-unicode" => "homebrew/x11",
  "s3-backer" => "homebrew/fuse",
  "s3fs" => "homebrew/fuse",
  "salt" => "homebrew/science",
  "scantailor" => "homebrew/x11",
  "sdelta3" => "homebrew/boneyard",
  "sedna" => "homebrew/boneyard",
  "shark" => "homebrew/science",
  "shell.fm" => "homebrew/boneyard",
  "simple-mtpfs" => "homebrew/fuse",
  "sitecopy" => "homebrew/boneyard",
  "slicot" => "homebrew/science",
  "smartsim" => "homebrew/gui",
  "solfege" => "homebrew/boneyard",
  "sptk" => "homebrew/x11",
  "sshfs" => "homebrew/fuse",
  "stormfs" => "homebrew/fuse",
  "sundials" => "homebrew/science",
  "swi-prolog" => "homebrew/x11",
  "sxiv" => "homebrew/x11",
  "synfigstudio" => "homebrew/boneyard",
  "syslog-ng" => "homebrew/boneyard",
  "tabbed" => "homebrew/x11",
  "telepathy-gabble" => "homebrew/boneyard",
  "telepathy-glib" => "homebrew/boneyard",
  "telepathy-idle" => "homebrew/boneyard",
  "telepathy-mission-control" => "homebrew/boneyard",
  "terminator" => "homebrew/gui",
  "tetgen" => "homebrew/science",
  "texmacs" => "homebrew/boneyard",
  "texwrapper" => "homebrew/tex",
  "threadscope" => "homebrew/gui",
  "ticcutils" => "homebrew/science",
  "tiger-vnc" => "homebrew/x11",
  "timbl" => "homebrew/science",
  "tmap" => "homebrew/boneyard",
  "transmission-remote-gtk" => "homebrew/gui",
  "tup" => "homebrew/fuse",
  "uim" => "homebrew/x11",
  "ume" => "homebrew/games",
  "upnp-router-control" => "homebrew/gui",
  "urweb" => "homebrew/boneyard",
  "ushare" => "homebrew/boneyard",
  "viewglob" => "homebrew/boneyard",
  "vobcopy" => "homebrew/boneyard",
  "wdfs" => "homebrew/fuse",
  "whereami" => "homebrew/boneyard",
  "why3" => "homebrew/tex",
  "wkhtmltopdf" => "homebrew/boneyard",
  "wmctrl" => "homebrew/x11",
  "wopr" => "homebrew/science",
  "wps2odt" => "homebrew/boneyard",
  "x3270" => "homebrew/x11",
  "xar" => "homebrew/dupes",
  "xastir" => "homebrew/x11",
  "xchat" => "homebrew/gui",
  "xclip" => "homebrew/x11",
  "xdotool" => "homebrew/x11",
  "xdu" => "homebrew/x11",
  "xmount" => "homebrew/fuse",
  "xournal" => "homebrew/gui",
  "xpa" => "homebrew/x11",
  "xpdf" => "homebrew/x11",
  "xplot" => "homebrew/x11",
  "xspringies" => "homebrew/x11",
  "xulrunner" => "homebrew/boneyard",
  "yarp" => "homebrew/x11",
  "ydict" => "homebrew/boneyard",
}
